Index: webrtc/modules/video_coding/encoded_frame.h |
diff --git a/webrtc/modules/video_coding/encoded_frame.h b/webrtc/modules/video_coding/encoded_frame.h |
index 840cd2056d594562799957559948f461e24b56a7..96f9d00d06e77780e9e6b5ac7b9f3125d63396f1 100644 |
--- a/webrtc/modules/video_coding/encoded_frame.h |
+++ b/webrtc/modules/video_coding/encoded_frame.h |
@@ -77,8 +77,12 @@ |
*/ |
VideoRotation rotation() const { return rotation_; } |
/** |
- * True if this frame is complete, false otherwise |
- */ |
+ * Get video content type |
+ */ |
+ VideoContentType contentType() const { return content_type_; } |
+ /** |
+ * True if this frame is complete, false otherwise |
+ */ |
bool Complete() const { return _completeFrame; } |
/** |
* True if there's a frame missing before this frame |